# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AddResourceRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resource_name': 'str',
        'resource_details': 'object',
        'credential_uri': 'str',
        'type': 'str',
        'sub_type': 'str',
        'credential_id': 'int'
    }

    attribute_map = {
        'resource_name': 'resourceName',
        'resource_details': 'resourceDetails',
        'credential_uri': 'credentialUri',
        'type': 'type',
        'sub_type': 'subType',
        'credential_id': 'credentialId'
    }

    def __init__(self, resource_name=None, resource_details=None, credential_uri=None, type=None, sub_type=None, credential_id=None):  # noqa: E501
        """AddResourceRequest - a model defined in Swagger"""  # noqa: E501

        self._resource_name = None
        self._resource_details = None
        self._credential_uri = None
        self._type = None
        self._sub_type = None
        self._credential_id = None
        self.discriminator = None

        if resource_name is not None:
            self.resource_name = resource_name
        if resource_details is not None:
            self.resource_details = resource_details
        if credential_uri is not None:
            self.credential_uri = credential_uri
        if type is not None:
            self.type = type
        if sub_type is not None:
            self.sub_type = sub_type
        if credential_id is not None:
            self.credential_id = credential_id

    @property
    def resource_name(self):
        """Gets the resource_name of this AddResourceRequest.  # noqa: E501

        Name of the new resource  # noqa: E501

        :return: The resource_name of this AddResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """Sets the resource_name of this AddResourceRequest.

        Name of the new resource  # noqa: E501

        :param resource_name: The resource_name of this AddResourceRequest.  # noqa: E501
        :type: str
        """

        self._resource_name = resource_name

    @property
    def resource_details(self):
        """Gets the resource_details of this AddResourceRequest.  # noqa: E501

        One of the resource details object  # noqa: E501

        :return: The resource_details of this AddResourceRequest.  # noqa: E501
        :rtype: object
        """
        return self._resource_details

    @resource_details.setter
    def resource_details(self, resource_details):
        """Sets the resource_details of this AddResourceRequest.

        One of the resource details object  # noqa: E501

        :param resource_details: The resource_details of this AddResourceRequest.  # noqa: E501
        :type: object
        """

        self._resource_details = resource_details

    @property
    def credential_uri(self):
        """Gets the credential_uri of this AddResourceRequest.  # noqa: E501

        URI of the credentials. If this is present, you can leave out the 'credentialId'  # noqa: E501

        :return: The credential_uri of this AddResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._credential_uri

    @credential_uri.setter
    def credential_uri(self, credential_uri):
        """Sets the credential_uri of this AddResourceRequest.

        URI of the credentials. If this is present, you can leave out the 'credentialId'  # noqa: E501

        :param credential_uri: The credential_uri of this AddResourceRequest.  # noqa: E501
        :type: str
        """

        self._credential_uri = credential_uri

    @property
    def type(self):
        """Gets the type of this AddResourceRequest.  # noqa: E501

        Resource type (whether COMPUTE or STORAGE)  # noqa: E501

        :return: The type of this AddResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AddResourceRequest.

        Resource type (whether COMPUTE or STORAGE)  # noqa: E501

        :param type: The type of this AddResourceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["COMPUTE", "STORAGE"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def sub_type(self):
        """Gets the sub_type of this AddResourceRequest.  # noqa: E501

        Resource subtype (COMPUTE -> [EMR, DataProc, HDInsight, YARN] | STORAGE -> [S3, GoogleStorage, AzureStorage, HDFS])  # noqa: E501

        :return: The sub_type of this AddResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._sub_type

    @sub_type.setter
    def sub_type(self, sub_type):
        """Sets the sub_type of this AddResourceRequest.

        Resource subtype (COMPUTE -> [EMR, DataProc, HDInsight, YARN] | STORAGE -> [S3, GoogleStorage, AzureStorage, HDFS])  # noqa: E501

        :param sub_type: The sub_type of this AddResourceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["EMR", "S3", "GoogleStorage", "DataProc", "HDInsight", "AzureStorage", "HDFS", "YARN"]  # noqa: E501
        if sub_type not in allowed_values:
            raise ValueError(
                "Invalid value for `sub_type` ({0}), must be one of {1}"  # noqa: E501
                .format(sub_type, allowed_values)
            )

        self._sub_type = sub_type

    @property
    def credential_id(self):
        """Gets the credential_id of this AddResourceRequest.  # noqa: E501

        ID of the credentials. If this is given then you can leave out the 'credentialsUri'  # noqa: E501

        :return: The credential_id of this AddResourceRequest.  # noqa: E501
        :rtype: int
        """
        return self._credential_id

    @credential_id.setter
    def credential_id(self, credential_id):
        """Sets the credential_id of this AddResourceRequest.

        ID of the credentials. If this is given then you can leave out the 'credentialsUri'  # noqa: E501

        :param credential_id: The credential_id of this AddResourceRequest.  # noqa: E501
        :type: int
        """

        self._credential_id = credential_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddResourceRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from skil_client.models.ind_array import INDArray  # noqa: F401,E501


class Prediction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'needs_pre_processing': 'bool',
        'prediction': 'INDArray',
        'input_mask': 'INDArray'
    }

    attribute_map = {
        'id': 'id',
        'needs_pre_processing': 'needsPreProcessing',
        'prediction': 'prediction',
        'input_mask': 'inputMask'
    }

    def __init__(self, id=None, needs_pre_processing=None, prediction=None, input_mask=None):  # noqa: E501
        """Prediction - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._needs_pre_processing = None
        self._prediction = None
        self._input_mask = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if needs_pre_processing is not None:
            self.needs_pre_processing = needs_pre_processing
        if prediction is not None:
            self.prediction = prediction
        if input_mask is not None:
            self.input_mask = input_mask

    @property
    def id(self):
        """Gets the id of this Prediction.  # noqa: E501


        :return: The id of this Prediction.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Prediction.


        :param id: The id of this Prediction.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def needs_pre_processing(self):
        """Gets the needs_pre_processing of this Prediction.  # noqa: E501


        :return: The needs_pre_processing of this Prediction.  # noqa: E501
        :rtype: bool
        """
        return self._needs_pre_processing

    @needs_pre_processing.setter
    def needs_pre_processing(self, needs_pre_processing):
        """Sets the needs_pre_processing of this Prediction.


        :param needs_pre_processing: The needs_pre_processing of this Prediction.  # noqa: E501
        :type: bool
        """

        self._needs_pre_processing = needs_pre_processing

    @property
    def prediction(self):
        """Gets the prediction of this Prediction.  # noqa: E501


        :return: The prediction of this Prediction.  # noqa: E501
        :rtype: INDArray
        """
        return self._prediction

    @prediction.setter
    def prediction(self, prediction):
        """Sets the prediction of this Prediction.


        :param prediction: The prediction of this Prediction.  # noqa: E501
        :type: INDArray
        """

        self._prediction = prediction

    @property
    def input_mask(self):
        """Gets the input_mask of this Prediction.  # noqa: E501


        :return: The input_mask of this Prediction.  # noqa: E501
        :rtype: INDArray
        """
        return self._input_mask

    @input_mask.setter
    def input_mask(self, input_mask):
        """Sets the input_mask of this Prediction.


        :param input_mask: The input_mask of this Prediction.  # noqa: E501
        :type: INDArray
        """

        self._input_mask = input_mask

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Prediction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import skil_client
from skil_client.models.download_output_file_request import DownloadOutputFileRequest  # noqa: E501
from skil_client.rest import ApiException


class TestDownloadOutputFileRequest(unittest.TestCase):
    """DownloadOutputFileRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDownloadOutputFileRequest(self):
        """Test DownloadOutputFileRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = skil_client.models.download_output_file_request.DownloadOutputFileRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResourceCredentials(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'credential_id': 'int',
        'type': 'str',
        'name': 'str',
        'uri': 'str'
    }

    attribute_map = {
        'credential_id': 'credentialId',
        'type': 'type',
        'name': 'name',
        'uri': 'uri'
    }

    def __init__(self, credential_id=None, type=None, name=None, uri=None):  # noqa: E501
        """ResourceCredentials - a model defined in Swagger"""  # noqa: E501

        self._credential_id = None
        self._type = None
        self._name = None
        self._uri = None
        self.discriminator = None

        if credential_id is not None:
            self.credential_id = credential_id
        if type is not None:
            self.type = type
        if name is not None:
            self.name = name
        if uri is not None:
            self.uri = uri

    @property
    def credential_id(self):
        """Gets the credential_id of this ResourceCredentials.  # noqa: E501

        ID of the credentials  # noqa: E501

        :return: The credential_id of this ResourceCredentials.  # noqa: E501
        :rtype: int
        """
        return self._credential_id

    @credential_id.setter
    def credential_id(self, credential_id):
        """Sets the credential_id of this ResourceCredentials.

        ID of the credentials  # noqa: E501

        :param credential_id: The credential_id of this ResourceCredentials.  # noqa: E501
        :type: int
        """

        self._credential_id = credential_id

    @property
    def type(self):
        """Gets the type of this ResourceCredentials.  # noqa: E501

        Type of the credentials  # noqa: E501

        :return: The type of this ResourceCredentials.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResourceCredentials.

        Type of the credentials  # noqa: E501

        :param type: The type of this ResourceCredentials.  # noqa: E501
        :type: str
        """
        allowed_values = ["AWS", "Azure", "GoogleCloud", "Hadoop"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def name(self):
        """Gets the name of this ResourceCredentials.  # noqa: E501

        Name of the credentials  # noqa: E501

        :return: The name of this ResourceCredentials.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResourceCredentials.

        Name of the credentials  # noqa: E501

        :param name: The name of this ResourceCredentials.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def uri(self):
        """Gets the uri of this ResourceCredentials.  # noqa: E501

        URI of the credentials  # noqa: E501

        :return: The uri of this ResourceCredentials.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ResourceCredentials.

        URI of the credentials  # noqa: E501

        :param uri: The uri of this ResourceCredentials.  # noqa: E501
        :type: str
        """

        self._uri = uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceCredentials):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from skil_client.models.deployment_objects import DeploymentObjects  # noqa: F401,E501


class DeploymentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'deployment_slug': 'str',
        'status': 'str',
        'body': 'DeploymentObjects'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'deployment_slug': 'deploymentSlug',
        'status': 'status',
        'body': 'body'
    }

    def __init__(self, id=None, name=None, deployment_slug=None, status=None, body=None):  # noqa: E501
        """DeploymentResponse - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._deployment_slug = None
        self._status = None
        self._body = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if deployment_slug is not None:
            self.deployment_slug = deployment_slug
        if status is not None:
            self.status = status
        if body is not None:
            self.body = body

    @property
    def id(self):
        """Gets the id of this DeploymentResponse.  # noqa: E501


        :return: The id of this DeploymentResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeploymentResponse.


        :param id: The id of this DeploymentResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DeploymentResponse.  # noqa: E501


        :return: The name of this DeploymentResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeploymentResponse.


        :param name: The name of this DeploymentResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def deployment_slug(self):
        """Gets the deployment_slug of this DeploymentResponse.  # noqa: E501


        :return: The deployment_slug of this DeploymentResponse.  # noqa: E501
        :rtype: str
        """
        return self._deployment_slug

    @deployment_slug.setter
    def deployment_slug(self, deployment_slug):
        """Sets the deployment_slug of this DeploymentResponse.


        :param deployment_slug: The deployment_slug of this DeploymentResponse.  # noqa: E501
        :type: str
        """

        self._deployment_slug = deployment_slug

    @property
    def status(self):
        """Gets the status of this DeploymentResponse.  # noqa: E501


        :return: The status of this DeploymentResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DeploymentResponse.


        :param status: The status of this DeploymentResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def body(self):
        """Gets the body of this DeploymentResponse.  # noqa: E501


        :return: The body of this DeploymentResponse.  # noqa: E501
        :rtype: DeploymentObjects
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this DeploymentResponse.


        :param body: The body of this DeploymentResponse.  # noqa: E501
        :type: DeploymentObjects
        """

        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeploymentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ModelHistoryEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created': 'int',
        'model_history_id': 'str',
        'model_name': 'str',
        'model_labels': 'str'
    }

    attribute_map = {
        'created': 'created',
        'model_history_id': 'modelHistoryId',
        'model_name': 'modelName',
        'model_labels': 'modelLabels'
    }

    def __init__(self, created=None, model_history_id=None, model_name=None, model_labels=None):  # noqa: E501
        """ModelHistoryEntity - a model defined in Swagger"""  # noqa: E501

        self._created = None
        self._model_history_id = None
        self._model_name = None
        self._model_labels = None
        self.discriminator = None

        if created is not None:
            self.created = created
        if model_history_id is not None:
            self.model_history_id = model_history_id
        if model_name is not None:
            self.model_name = model_name
        if model_labels is not None:
            self.model_labels = model_labels

    @property
    def created(self):
        """Gets the created of this ModelHistoryEntity.  # noqa: E501

        When the model history / workspace was created  # noqa: E501

        :return: The created of this ModelHistoryEntity.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ModelHistoryEntity.

        When the model history / workspace was created  # noqa: E501

        :param created: The created of this ModelHistoryEntity.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def model_history_id(self):
        """Gets the model_history_id of this ModelHistoryEntity.  # noqa: E501

        The GUID of the model history / workspace  # noqa: E501

        :return: The model_history_id of this ModelHistoryEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_history_id

    @model_history_id.setter
    def model_history_id(self, model_history_id):
        """Sets the model_history_id of this ModelHistoryEntity.

        The GUID of the model history / workspace  # noqa: E501

        :param model_history_id: The model_history_id of this ModelHistoryEntity.  # noqa: E501
        :type: str
        """

        self._model_history_id = model_history_id

    @property
    def model_name(self):
        """Gets the model_name of this ModelHistoryEntity.  # noqa: E501

        Name of the model history / workspace  # noqa: E501

        :return: The model_name of this ModelHistoryEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this ModelHistoryEntity.

        Name of the model history / workspace  # noqa: E501

        :param model_name: The model_name of this ModelHistoryEntity.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def model_labels(self):
        """Gets the model_labels of this ModelHistoryEntity.  # noqa: E501

        Model history / workspace labels  # noqa: E501

        :return: The model_labels of this ModelHistoryEntity.  # noqa: E501
        :rtype: str
        """
        return self._model_labels

    @model_labels.setter
    def model_labels(self, model_labels):
        """Sets the model_labels of this ModelHistoryEntity.

        Model history / workspace labels  # noqa: E501

        :param model_labels: The model_labels of this ModelHistoryEntity.  # noqa: E501
        :type: str
        """

        self._model_labels = model_labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelHistoryEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
